Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.FamilieVersandartSchlank Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.FamilieVersandartSchlank einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.FamilieVersandartSchlank) | Gemeinde_Modelle.FamilieVersandartSchlank |
__str__(self) (Definiert in Gemeinde_Modelle.FamilieVersandartSchlank) | Gemeinde_Modelle.FamilieVersandartSchlank |
keyFeldNavi (Definiert in Gemeinde_Modelle.FamilieVersandartSchlank) | Gemeinde_Modelle.FamilieVersandartSchlank | static
R_familie (Definiert in Gemeinde_Modelle.FamilieVersandartSchlank) | Gemeinde_Modelle.FamilieVersandartSchlank | static
R_versandart (Definiert in Gemeinde_Modelle.FamilieVersandartSchlank) | Gemeinde_Modelle.FamilieVersandartSchlank | static